"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ctor_ensure_decorator_1 = require("./ctor-ensure.decorator");
/**
 * Validate a constructor from the k-v pairs of a plain object
 * @param className Schema name
 * @param value Plain object containing contructor fields
 * @param templateLang Language to use for rendering ensure templates
 * @returns List of errors
 */
var validateCtor = function (className, value, templateLang) {
    var _a;
    if (templateLang === void 0) { templateLang = ''; }
    // Find target class
    var clazz = (_a = ctor_ensure_decorator_1.classRegistry[className]) === null || _a === void 0 ? void 0 : _a.clazz;
    if (!clazz)
        return null;
    // Get all controls of this class and find the highest validated ctor index
    var ctls = (0, ctor_ensure_decorator_1.getActiveControls)(clazz, className, []);
    var maxCtorInd = ctls.reduce(function (acc, curr) { return (curr.ctorInd > acc ? curr.ctorInd : acc); }, 0);
    // Constructor arguments list, map value fields to their indices
    var ctorArgs = new Array(maxCtorInd + 1).fill(undefined);
    ctls.forEach(function (ctl) {
        var currValue = value[ctl.displayName];
        ctorArgs[ctl.ctorInd] = currValue;
    });
    // Call validation
    return (0, ctor_ensure_decorator_1.validateClassCtor)(className, ctorArgs, templateLang);
};
exports.default = validateCtor;
//# sourceMappingURL=ctor-validator.js.map